#!/usr/bin/env python
#-*-coding: utf-8-*-

import os

from cogent.parse.fasta import MinimalFastaParser
from cogent.util.transform import make_trans

from sglib.translator import translate_lines
from sglib.quartet import quartet_generator, AverageBinaryQuartet
from sglib.utils import calc_t_likeliness, calc_b_likeliness

TEST_DIR = "test_data"

def main(input_dir=TEST_DIR):
    """Runs everything"""
    # STEP 1: read input, get processable input
    parser_1 = MinimalFastaParser(open(os.path.join(input_dir, "A.SSQ")))
    parser_2 = MinimalFastaParser(open(os.path.join(input_dir, "B.SSQ")))
    parser_3 = MinimalFastaParser(open(os.path.join(input_dir, "C.SSQ")))
    parser_4 = MinimalFastaParser(open(os.path.join(input_dir, "D.SSQ")))
    # 56 quartets from these four files can be created!
    
    # STEP 2: make suitable translation table
    DNA_BINARY = make_trans('TCAG', '1100', default='-')
    
    # STEP 3: do the translation
    translation_1 = translate_lines(parser_1, DNA_BINARY)
    translation_2 = translate_lines(parser_2, DNA_BINARY)
    translation_3 = translate_lines(parser_3, DNA_BINARY)
    translation_4 = translate_lines(parser_4, DNA_BINARY)
    
    # STEP 4: make AverageBinaryQuartet and let it calculate params
    avg_quartet = AverageBinaryQuartet()
    for quartet in quartet_generator(\
    translation_1, translation_2, translation_3, translation_4, mode='B'):
        quartet.analyze()
        avg_quartet.update(quartet)
    avg_quartet.calculateAverages()
    
    return avg_quartet

if __name__ == "__main__":
    avg_quartet = main(input_dir=TEST_DIR)
    print
    print 'Tree/bundle-likeliness:'
    print '%25s %10f' % ('tree-likeliness', calc_t_likeliness(avg_quartet))
    print '%25s %10f' % ('bundle-likeliness', calc_b_likeliness(avg_quartet))
    print
    print 'Protrusions:'
    print '%25s %10s' % ('alpha', str(avg_quartet.Alpha))
    print '%25s %10s' % ('beta', str(avg_quartet.Beta))
    print '%25s %10s' % ('gamma', str(avg_quartet.Gamma))
    print '%25s %10s' % ('delta', str(avg_quartet.Delta))
    print '%25s %10f' % ('average', avg_quartet.Protrusion)
    print
    print 'Box dimensions:'
    print '%25s %10s' % ('AB', str(avg_quartet.AB))
    print '%25s %10s' % ('AC', str(avg_quartet.AC))
    print '%25s %10s' % ('AD', str(avg_quartet.AD))
    print '%25s %10s' % ('small', avg_quartet.SmallBox)
    print '%25s %10s' % ('medium', avg_quartet.MediumBox)
    print '%25s %10s' % ('large', avg_quartet.LargeBox)
    print
    
