#!/usr/bin/env python
#-*-coding: utf-8-*-

import os

from cogent.parse.fasta import MinimalFastaParser
from cogent.util.transform import make_trans

from sglib.translator import translate_lines
from sglib.quartet import quartet_generator, AverageBinaryQuartet
from sglib.utils import calc_t_likeliness, calc_b_likeliness

TEST_DIR = "test_data"

def main(input_dir=TEST_DIR):
    """Calculates the geometry parameters for a single sequence alignment
    
        input_dir: str, a path to directory with input files
    """
    # STEP 1: read input, get processable input
    parser = MinimalFastaParser(open(os.path.join(input_dir, "D.SSQ")))
    
    # STEP 2: make suitable translation table
    DNA_BINARY = make_trans('TCAG', '1100', default='-')
    
    # STEP 3: do the translation
    translation = translate_lines(parser, DNA_BINARY)
    
    # STEP 4: make AverageBinaryQuartet and let it calculate params
    avg_quartet = AverageBinaryQuartet()
    for quartet in quartet_generator(translation, mode='B'):
        quartet.analyze()
        avg_quartet.update(quartet)
    avg_quartet.calculateAverages()
    return avg_quartet
    
if __name__ == "__main__":
    avg_quartet = main(input_dir=TEST_DIR)
    print
    print 'Tree/bundle-likeliness:'
    print '%25s %10f' % ('tree-likeliness', calc_t_likeliness(avg_quartet))
    print '%25s %10f' % ('bundle-likeliness', calc_b_likeliness(avg_quartet))
    print
    

